=========================
AMaaS Core SDK for Python
=========================

This is the Asset Management as a Service (AMaaS) Software Development Kit (SDK)
for Python.


Quick Start
-----------
Install the AMaaS Core library from PyPI:

.. code-block:: sh

    $ pip install amaascore


To be completed.
